PillSourceImpl

Trait PillSourceImpl 

pub trait PillSourceImpl: ObjectImpl {
    // Required method
    fn identifier(&self) -> String;
}
Public trait that must be implemented for everything that derives from PillSource.

Overriding a method from this Trait overrides also its behavior in PillSourceExt.

Required Methods

fn identifier(&self) -> String

A unique identifier for this source.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors